.. -*- mode: rst -*-

|CircleCI|_ |Codecov|_ |PyPi|_ |Zenhub|_ 

.. |CircleCI| image:: https://circleci.com/gh/neuro-ml/edr-gp/tree/master.svg?style=shield&circle-token=:circle-token
.. _CircleCI: https://circleci.com/gh/neuro-ml/edr-gp

.. |Codecov| image:: https://codecov.io/github/neuro-ml/edr-gp/badge.svg?branch=master&service=github
.. _Codecov: https://codecov.io/github/?branch=master

.. |PyPi| image:: https://badge.fury.io/py/edr-gp.svg
.. _PyPi: https://badge.fury.io/py/edr-gp

.. |Zenhub| image:: https://img.shields.io/badge/Shipping_faster_with-ZenHub-5e60ba.svg?style=flat-square
.. _Zenhub: https://zenhub.com

edr-gp
============

A library for sparse effective (functional) dimensionality reduction via Gaussian Processes
